@@ -5,9 +5,11 @@ from . import core
 
 importlib.reload(core)
 
+
 def load_ipython_extension(ipython):
     ipython.register_magics(IgniteMagic)
 
+
 # Defines the "magic" that will be used inside the cells
 @magics_class
 class IgniteMagic(Magics):
@@ -18,31 +20,34 @@ class IgniteMagic(Magics):
 
         globals_dict = {}
         locals_dict = {}
-        
+
         self.core_obj = core.Core(globals_dict)
-        
+
         # Copy global constants from Core object
         for key, val in core.Core.global_constants.items():
             globals_dict[key] = val
-    
-        # Copy global methods from Core object
-        for field in core.Core.global_fields:
-            globals_dict[field] = getattr(self.core_obj, field)
+
+        for field, mutable in core.Core.ignite_globals.items():
+            if not mutable:
+                globals_dict[field] = getattr(self.core_obj, field)
 
         # Execute the code inside the cell and inject the globals we defined.
         try:
             exec(cell_code, globals_dict, locals_dict)
         except Exception as e:
             print("Error: " + str(e))
-        
+
         # Look at all methods defined by user, and see if they overwrote anything useful
         methods = {}
         for key, val in locals_dict.items():
-            if key in core.Core.global_methods:
-                methods[key] = val      # Track the global methods and pass to the core_obj.
+            mutable = core.Core.ignite_globals.get(key)
+            if mutable is None:
+                globals_dict[key] = val
+            elif mutable:
+                methods[key] = val
             else:
-                globals_dict[key] = val # Copy locals to global to keep them available.
-        
+                print(f'Error in cell: Attempted redefinition of immutable Spark global "{key}".')
+                return
+
         # Run bootstrap code
         self.core_obj.start(methods)
-        
